@@ -189,7 +189,7 @@ def test(production_name, job_name, dependent_input):
     with open(os.path.join(production_name, "info.yaml"), "rt") as fp:
         raw_yaml = fp.read()
     prod_data, checks_data = parse_yaml(render_yaml(raw_yaml))
-    warnings = validate_yaml(prod_data, checks_data, ".", production_name)
+    yaml_warnings = validate_yaml(prod_data, checks_data, ".", production_name)
     try:
         job_data = prod_data[job_name]
     except KeyError:
@@ -200,27 +200,55 @@ def test(production_name, job_name, dependent_input):
 
     # Validating Gaudi options
     test_ntuple_path = join(out_dir, f"00012345_00006789_1.{output_file}")
-    errors = do_options_parsing(
-        env_cmd,
-        out_dir,
-        join(out_dir, "output.pkl"),
-        test_ntuple_path,
-    )
+
+    errors, warnings = [], []
+    if os.path.isfile(test_ntuple_path):
+        if ".root" in test_ntuple_path.lower():
+            errors, warnings = do_options_parsing(
+                env_cmd,
+                out_dir,
+                join(out_dir, "output.pkl"),
+                test_ntuple_path,
+                job_data,
+                prod_data,
+            )
+    else:
+        if any(
+            test_ntuple_path.lower() == join(out_dir, name).lower()
+            for name in os.listdir(out_dir)
+        ):
+            warnings = [
+                "The output file has a different capitalisation to what is expected!"
+                " If this is a stripping job it could be due to a custom_stream"
+                " name not being written in all capital letters."
+            ]
+        else:
+            raise click.ClickException(
+                "ERROR: The expected output file does not exist!"
+            )
+
+    warnings.extend(yaml_warnings)
+    if warnings:
+        for warning in warnings:
+            click.secho(f"WARNING: {warning}", fg="yellow")
+
     if errors:
         raise click.ClickException(
             "Found the following errors when parsing the options:"
             + "\n  * "
             + "\n  * ".join(errors)
         )
-    click.secho("No problems found while validating the Gaudi options", fg="green")
+    if not any([warnings, errors]):
+        click.secho(
+            "No problems found while validating the options and output file!",
+            fg="green",
+        )
 
     # Run checks
     if checks_exist(checks_data):
         checks_output_dir = join(out_dir, "checks")
         perform_checks(production_name, job_name, [test_ntuple_path], checks_output_dir)
 
-    for warning in warnings:
-        click.secho(f"WARNING: {warning}", fg="yellow")
     # The functionality of job-dependent job testing relies on out_dir being written
     # in the line below as the final word so please be careful if changing the below line
     click.secho(f"Success! Output can be found in {out_dir}", fg="green")
