@@ -249,7 +249,7 @@ def enter_debugging(out_dir, env_cmd, gaudi_cmd, dependent_job=None):
     os.execlp(cmd[0], *cmd)
 
 
-def do_options_parsing(env_cmd, out_dir, pkl_file, root_file):
+def do_options_parsing(env_cmd, out_dir, pkl_file, root_file, job_data, prod_data):
     json_file = join(out_dir, "output.json")
 
     with importlib.resources.path(
@@ -268,4 +268,4 @@ def do_options_parsing(env_cmd, out_dir, pkl_file, root_file):
             ],
             text=True,
         )
-    return validate_options(json_file, root_file)
+    return validate_options(json_file, root_file, job_data, prod_data)
